# Web Traffic Dashboard

_Generated: 2026-03-13 04:55:25_

## Artifacts

- [bar_1.png](assets/bar_1.png)
- [traffic_by_device.png](assets/traffic_by_device.png)
- [top_pages.png](assets/top_pages.png)
- [conversion_funnel.png](assets/conversion_funnel.png)
- [conversions_by_source.png](assets/conversions_by_source.png)
- [line_2.png](assets/line_2.png)


---

## Traffic Overview

| **Pageviews** | **Sessions** | **Unique Visitors** | **Avg Duration (s)** |
| :---: | :---: | :---: | :---: |
| **30** | **20** | **19** | **93.0** |


---

## Traffic by Source

![Pageviews by Source](assets/bar_1.png)

*Pageviews by Source*


---

## Traffic by Device

![Device distribution](assets/traffic_by_device.png)

*Device distribution*


---

## Top Pages

![Pages ranked by views with average duration](assets/top_pages.png)

*Pages ranked by views with average duration*


---

## Conversion Funnel

![Conversion funnel from session to purchase](assets/conversion_funnel.png)

*Conversion funnel from session to purchase*


---

## Conversions by Source

![Sessions vs conversions by source](assets/conversions_by_source.png)

*Sessions vs conversions by source*


---

## Daily Traffic Trend

![Daily Traffic Trend](assets/line_2.png)

*Daily Traffic Trend*


---

